==> prefab-cloud-java-0.0.1-sources.jar: cloud/prefab/domain/RateLimitServiceGrpc.java <==
package cloud.prefab.domain;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.11.0)",
    comments = "Source: prefab.proto")
public final class RateLimitServiceGrpc {

  private RateLimitServiceGrpc() {}

  public static final String SERVICE_NAME = "prefab.RateLimitService";

  // Static method descriptors that strictly reflect the proto.
  @io.grpc.ExperimentalApi("https://github.com/grpc/grpc-java/issues/1901")
  @java.lang.Deprecated // Use {@link #getLimitCheckMethod()} instead. 
  public static final io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitRequest,
      cloud.prefab.domain.Prefab.LimitResponse> METHOD_LIMIT_CHECK = getLimitCheckMethodHelper();

  private static volatile io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitRequest,
      cloud.prefab.domain.Prefab.LimitResponse> getLimitCheckMethod;

  @io.grpc.ExperimentalApi("https://github.com/grpc/grpc-java/issues/1901")
  public static io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitRequest,
      cloud.prefab.domain.Prefab.LimitResponse> getLimitCheckMethod() {
    return getLimitCheckMethodHelper();
  }

  private static io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitRequest,
      cloud.prefab.domain.Prefab.LimitResponse> getLimitCheckMethodHelper() {
    io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitRequest, cloud.prefab.domain.Prefab.LimitResponse> getLimitCheckMethod;
    if ((getLimitCheckMethod = RateLimitServiceGrpc.getLimitCheckMethod) == null) {
      synchronized (RateLimitServiceGrpc.class) {
        if ((getLimitCheckMethod = RateLimitServiceGrpc.getLimitCheckMethod) == null) {
          RateLimitServiceGrpc.getLimitCheckMethod = getLimitCheckMethod = 
              io.grpc.MethodDescriptor.<cloud.prefab.domain.Prefab.LimitRequest, cloud.prefab.domain.Prefab.LimitResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(
                  "prefab.RateLimitService", "LimitCheck"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.LimitRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.LimitResponse.getDefaultInstance()))
                  .setSchemaDescriptor(new RateLimitServiceMethodDescriptorSupplier("LimitCheck"))
                  .build();
          }
        }
     }
     return getLimitCheckMethod;
  }
  @io.grpc.ExperimentalApi("https://github.com/grpc/grpc-java/issues/1901")
  @java.lang.Deprecated // Use {@link #getUpsertLimitDefinitionMethod()} instead. 
  public static final io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitDefinition,
      cloud.prefab.domain.Prefab.BasicResponse> METHOD_UPSERT_LIMIT_DEFINITION = getUpsertLimitDefinitionMethodHelper();

  private static volatile io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitDefinition,
      cloud.prefab.domain.Prefab.BasicResponse> getUpsertLimitDefinitionMethod;

  @io.grpc.ExperimentalApi("https://github.com/grpc/grpc-java/issues/1901")
  public static io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitDefinition,
      cloud.prefab.domain.Prefab.BasicResponse> getUpsertLimitDefinitionMethod() {
    return getUpsertLimitDefinitionMethodHelper();
  }

  private static io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitDefinition,
      cloud.prefab.domain.Prefab.BasicResponse> getUpsertLimitDefinitionMethodHelper() {
    io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitDefinition, cloud.prefab.domain.Prefab.BasicResponse> getUpsertLimitDefinitionMethod;
    if ((getUpsertLimitDefinitionMethod = RateLimitServiceGrpc.getUpsertLimitDefinitionMethod) == null) {
      synchronized (RateLimitServiceGrpc.class) {
        if ((getUpsertLimitDefinitionMethod = RateLimitServiceGrpc.getUpsertLimitDefinitionMethod) == null) {
          RateLimitServiceGrpc.getUpsertLimitDefinitionMethod = getUpsertLimitDefinitionMethod = 
              io.grpc.MethodDescriptor.<cloud.prefab.domain.Prefab.LimitDefinition, cloud.prefab.domain.Prefab.BasicResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(
                  "prefab.RateLimitService", "UpsertLimitDefinition"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.LimitDefinition.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.BasicResponse.getDefaultInstance()))
                  .setSchemaDescriptor(new RateLimitServiceMethodDescriptorSupplier("UpsertLimitDefinition"))
                  .build();
          }
        }
     }
     return getUpsertLimitDefinitionMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static RateLimitServiceStub newStub(io.grpc.Channel channel) {
    return new RateLimitServiceStub(channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static RateLimitServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    return new RateLimitServiceBlockingStub(channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static RateLimitServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    return new RateLimitServiceFutureStub(channel);
  }

  /**
   */
  public static abstract class RateLimitServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void limitCheck(cloud.prefab.domain.Prefab.LimitRequest request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.LimitResponse> responseObserver) {
      asyncUnimplementedUnaryCall(getLimitCheckMethodHelper(), responseObserver);
    }

    /**
     */
    public void upsertLimitDefinition(cloud.prefab.domain.Prefab.LimitDefinition request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.BasicResponse> responseObserver) {
      asyncUnimplementedUnaryCall(getUpsertLimitDefinitionMethodHelper(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getLimitCheckMethodHelper(),
            asyncUnaryCall(
              new MethodHandlers<
                cloud.prefab.domain.Prefab.LimitRequest,
                cloud.prefab.domain.Prefab.LimitResponse>(
                  this, METHODID_LIMIT_CHECK)))
          .addMethod(
            getUpsertLimitDefinitionMethodHelper(),
            asyncUnaryCall(
              new MethodHandlers<
                cloud.prefab.domain.Prefab.LimitDefinition,
                cloud.prefab.domain.Prefab.BasicResponse>(
                  this, METHODID_UPSERT_LIMIT_DEFINITION)))
          .build();
    }
  }

  /**
   */
  public static final class RateLimitServiceStub extends io.grpc.stub.AbstractStub<RateLimitServiceStub> {
    private RateLimitServiceStub(io.grpc.Channel channel) {
      super(channel);
    }

    private RateLimitServiceStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected RateLimitServiceStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new RateLimitServiceStub(channel, callOptions);
    }

    /**
     */
    public void limitCheck(cloud.prefab.domain.Prefab.LimitRequest request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.LimitResponse> responseObserver) {
      asyncUnaryCall(
          getChannel().newCall(getLimitCheckMethodHelper(), getCallOptions()), request, responseObserver);
    }

    /**
     */
    public void upsertLimitDefinition(cloud.prefab.domain.Prefab.LimitDefinition request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.BasicResponse> responseObserver) {
      asyncUnaryCall(
          getChannel().newCall(getUpsertLimitDefinitionMethodHelper(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class RateLimitServiceBlockingStub extends io.grpc.stub.AbstractStub<RateLimitServiceBlockingStub> {
    private RateLimitServiceBlockingStub(io.grpc.Channel channel) {
      super(channel);
    }

    private RateLimitServiceBlockingStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected RateLimitServiceBlockingStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new RateLimitServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public cloud.prefab.domain.Prefab.LimitResponse limitCheck(cloud.prefab.domain.Prefab.LimitRequest request) {
      return blockingUnaryCall(
          getChannel(), getLimitCheckMethodHelper(), getCallOptions(), request);
    }

    /**
     */
    public cloud.prefab.domain.Prefab.BasicResponse upsertLimitDefinition(cloud.prefab.domain.Prefab.LimitDefinition request) {
      return blockingUnaryCall(
          getChannel(), getUpsertLimitDefinitionMethodHelper(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class RateLimitServiceFutureStub extends io.grpc.stub.AbstractStub<RateLimitServiceFutureStub> {
    private RateLimitServiceFutureStub(io.grpc.Channel channel) {
      super(channel);
    }

    private RateLimitServiceFutureStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected RateLimitServiceFutureStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new RateLimitServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<cloud.prefab.domain.Prefab.LimitResponse> limitCheck(
        cloud.prefab.domain.Prefab.LimitRequest request) {
      return futureUnaryCall(
          getChannel().newCall(getLimitCheckMethodHelper(), getCallOptions()), request);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<cloud.prefab.domain.Prefab.BasicResponse> upsertLimitDefinition(
        cloud.prefab.domain.Prefab.LimitDefinition request) {
      return futureUnaryCall(
          getChannel().newCall(getUpsertLimitDefinitionMethodHelper(), getCallOptions()), request);
    }
  }

  private static final int METHODID_LIMIT_CHECK = 0;
  private static final int METHODID_UPSERT_LIMIT_DEFINITION = 1;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final RateLimitServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(RateLimitServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_LIMIT_CHECK:
          serviceImpl.limitCheck((cloud.prefab.domain.Prefab.LimitRequest) request,
              (io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.LimitResponse>) responseObserver);
          break;
        case METHODID_UPSERT_LIMIT_DEFINITION:
          serviceImpl.upsertLimitDefinition((cloud.prefab.domain.Prefab.LimitDefinition) request,
              (io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.BasicResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class RateLimitServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    RateLimitServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return cloud.prefab.domain.Prefab.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("RateLimitService");
    }
  }

  private static final class RateLimitServiceFileDescriptorSupplier
      extends RateLimitServiceBaseDescriptorSupplier {
    RateLimitServiceFileDescriptorSupplier() {}
  }

  private static final class RateLimitServiceMethodDescriptorSupplier
      extends RateLimitServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    RateLimitServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (RateLimitServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new RateLimitServiceFileDescriptorSupplier())
              .addMethod(getLimitCheckMethodHelper())
              .addMethod(getUpsertLimitDefinitionMethodHelper())
              .build();
        }
      }
    }
    return result;
  }
}

==> prefab-cloud-java-0.0.7-sources.jar: cloud/prefab/domain/RateLimitServiceGrpc.java <==
package cloud.prefab.domain;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.15.0)",
    comments = "Source: prefab.proto")
public final class RateLimitServiceGrpc {

  private RateLimitServiceGrpc() {}

  public static final String SERVICE_NAME = "prefab.RateLimitService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitRequest,
      cloud.prefab.domain.Prefab.LimitResponse> getLimitCheckMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "LimitCheck",
      requestType = cloud.prefab.domain.Prefab.LimitRequest.class,
      responseType = cloud.prefab.domain.Prefab.LimitResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitRequest,
      cloud.prefab.domain.Prefab.LimitResponse> getLimitCheckMethod() {
    io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitRequest, cloud.prefab.domain.Prefab.LimitResponse> getLimitCheckMethod;
    if ((getLimitCheckMethod = RateLimitServiceGrpc.getLimitCheckMethod) == null) {
      synchronized (RateLimitServiceGrpc.class) {
        if ((getLimitCheckMethod = RateLimitServiceGrpc.getLimitCheckMethod) == null) {
          RateLimitServiceGrpc.getLimitCheckMethod = getLimitCheckMethod = 
              io.grpc.MethodDescriptor.<cloud.prefab.domain.Prefab.LimitRequest, cloud.prefab.domain.Prefab.LimitResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(
                  "prefab.RateLimitService", "LimitCheck"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.LimitRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.LimitResponse.getDefaultInstance()))
                  .setSchemaDescriptor(new RateLimitServiceMethodDescriptorSupplier("LimitCheck"))
                  .build();
          }
        }
     }
     return getLimitCheckMethod;
  }

  private static volatile io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitDefinition,
      cloud.prefab.domain.Prefab.BasicResponse> getUpsertLimitDefinitionMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "UpsertLimitDefinition",
      requestType = cloud.prefab.domain.Prefab.LimitDefinition.class,
      responseType = cloud.prefab.domain.Prefab.BasicResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitDefinition,
      cloud.prefab.domain.Prefab.BasicResponse> getUpsertLimitDefinitionMethod() {
    io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.LimitDefinition, cloud.prefab.domain.Prefab.BasicResponse> getUpsertLimitDefinitionMethod;
    if ((getUpsertLimitDefinitionMethod = RateLimitServiceGrpc.getUpsertLimitDefinitionMethod) == null) {
      synchronized (RateLimitServiceGrpc.class) {
        if ((getUpsertLimitDefinitionMethod = RateLimitServiceGrpc.getUpsertLimitDefinitionMethod) == null) {
          RateLimitServiceGrpc.getUpsertLimitDefinitionMethod = getUpsertLimitDefinitionMethod = 
              io.grpc.MethodDescriptor.<cloud.prefab.domain.Prefab.LimitDefinition, cloud.prefab.domain.Prefab.BasicResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(
                  "prefab.RateLimitService", "UpsertLimitDefinition"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.LimitDefinition.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.BasicResponse.getDefaultInstance()))
                  .setSchemaDescriptor(new RateLimitServiceMethodDescriptorSupplier("UpsertLimitDefinition"))
                  .build();
          }
        }
     }
     return getUpsertLimitDefinitionMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static RateLimitServiceStub newStub(io.grpc.Channel channel) {
    return new RateLimitServiceStub(channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static RateLimitServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    return new RateLimitServiceBlockingStub(channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static RateLimitServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    return new RateLimitServiceFutureStub(channel);
  }

  /**
   */
  public static abstract class RateLimitServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void limitCheck(cloud.prefab.domain.Prefab.LimitRequest request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.LimitResponse> responseObserver) {
      asyncUnimplementedUnaryCall(getLimitCheckMethod(), responseObserver);
    }

    /**
     */
    public void upsertLimitDefinition(cloud.prefab.domain.Prefab.LimitDefinition request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.BasicResponse> responseObserver) {
      asyncUnimplementedUnaryCall(getUpsertLimitDefinitionMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getLimitCheckMethod(),
            asyncUnaryCall(
              new MethodHandlers<
                cloud.prefab.domain.Prefab.LimitRequest,
                cloud.prefab.domain.Prefab.LimitResponse>(
                  this, METHODID_LIMIT_CHECK)))
          .addMethod(
            getUpsertLimitDefinitionMethod(),
            asyncUnaryCall(
              new MethodHandlers<
                cloud.prefab.domain.Prefab.LimitDefinition,
                cloud.prefab.domain.Prefab.BasicResponse>(
                  this, METHODID_UPSERT_LIMIT_DEFINITION)))
          .build();
    }
  }

  /**
   */
  public static final class RateLimitServiceStub extends io.grpc.stub.AbstractStub<RateLimitServiceStub> {
    private RateLimitServiceStub(io.grpc.Channel channel) {
      super(channel);
    }

    private RateLimitServiceStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected RateLimitServiceStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new RateLimitServiceStub(channel, callOptions);
    }

    /**
     */
    public void limitCheck(cloud.prefab.domain.Prefab.LimitRequest request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.LimitResponse> responseObserver) {
      asyncUnaryCall(
          getChannel().newCall(getLimitCheckMethod(), getCallOptions()), request, responseObserver);
    }

    /**
     */
    public void upsertLimitDefinition(cloud.prefab.domain.Prefab.LimitDefinition request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.BasicResponse> responseObserver) {
      asyncUnaryCall(
          getChannel().newCall(getUpsertLimitDefinitionMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class RateLimitServiceBlockingStub extends io.grpc.stub.AbstractStub<RateLimitServiceBlockingStub> {
    private RateLimitServiceBlockingStub(io.grpc.Channel channel) {
      super(channel);
    }

    private RateLimitServiceBlockingStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected RateLimitServiceBlockingStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new RateLimitServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public cloud.prefab.domain.Prefab.LimitResponse limitCheck(cloud.prefab.domain.Prefab.LimitRequest request) {
      return blockingUnaryCall(
          getChannel(), getLimitCheckMethod(), getCallOptions(), request);
    }

    /**
     */
    public cloud.prefab.domain.Prefab.BasicResponse upsertLimitDefinition(cloud.prefab.domain.Prefab.LimitDefinition request) {
      return blockingUnaryCall(
          getChannel(), getUpsertLimitDefinitionMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class RateLimitServiceFutureStub extends io.grpc.stub.AbstractStub<RateLimitServiceFutureStub> {
    private RateLimitServiceFutureStub(io.grpc.Channel channel) {
      super(channel);
    }

    private RateLimitServiceFutureStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected RateLimitServiceFutureStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new RateLimitServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<cloud.prefab.domain.Prefab.LimitResponse> limitCheck(
        cloud.prefab.domain.Prefab.LimitRequest request) {
      return futureUnaryCall(
          getChannel().newCall(getLimitCheckMethod(), getCallOptions()), request);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<cloud.prefab.domain.Prefab.BasicResponse> upsertLimitDefinition(
        cloud.prefab.domain.Prefab.LimitDefinition request) {
      return futureUnaryCall(
          getChannel().newCall(getUpsertLimitDefinitionMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_LIMIT_CHECK = 0;
  private static final int METHODID_UPSERT_LIMIT_DEFINITION = 1;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final RateLimitServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(RateLimitServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_LIMIT_CHECK:
          serviceImpl.limitCheck((cloud.prefab.domain.Prefab.LimitRequest) request,
              (io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.LimitResponse>) responseObserver);
          break;
        case METHODID_UPSERT_LIMIT_DEFINITION:
          serviceImpl.upsertLimitDefinition((cloud.prefab.domain.Prefab.LimitDefinition) request,
              (io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.BasicResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class RateLimitServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    RateLimitServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return cloud.prefab.domain.Prefab.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("RateLimitService");
    }
  }

  private static final class RateLimitServiceFileDescriptorSupplier
      extends RateLimitServiceBaseDescriptorSupplier {
    RateLimitServiceFileDescriptorSupplier() {}
  }

  private static final class RateLimitServiceMethodDescriptorSupplier
      extends RateLimitServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    RateLimitServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (RateLimitServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new RateLimitServiceFileDescriptorSupplier())
              .addMethod(getLimitCheckMethod())
              .addMethod(getUpsertLimitDefinitionMethod())
              .build();
        }
      }
    }
    return result;
  }
}
